package com.caimei.controller;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.ClubVo;
import com.caimei.model.vo.ProductVo;
import com.caimei.service.ProductService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/3/23
 */
@Api(tags = "商品")
@RestController
@RequestMapping("/product")
public class ProductApi {

    private ProductService productService;

    @Autowired
    public void setProductService(ProductService productService) {
        this.productService = productService;
    }

    /**
     * 组织机构列表
     *
     * @param name       机构名称/机构联系人
     * @param organizeId 组织id
     * @return
     */
    @ApiOperation("机构列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "organizeId", required = true, value = "组织id"),
            @ApiImplicitParam(name = "name", required = false, value = "机构名称/机构联系人"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    @GetMapping("/clubList")
    public ResponseJson<PageInfo<ClubVo>> clubList(Integer organizeId, String name, Integer pageNum, Integer pageSize) {
        if (organizeId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return productService.clubList(organizeId, name, pageNum, pageSize);
    }


    /**
     * 立即下单商品列表
     *
     * @param organizeId        组织id
     * @param productName       商品名称
     * @return
     */
    @ApiOperation("立即下单商品列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "organizeId", required = true, value = "组织id"),
            @ApiImplicitParam(name = "productName", required = false, value = "商品名称"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    @GetMapping("/list")
    public ResponseJson<PageInfo<ProductVo>> productList(Integer organizeId, String productName,
                                                         @RequestParam(value = "pageNum", defaultValue = "1")Integer pageNum,
                                                         @RequestParam(value = "pageSize", defaultValue = "10")Integer pageSize) {
        return productService.productList(organizeId, productName, pageNum, pageSize);
    }

    /**
     * 商品详情
     *
     * @param productId        商品Id
     * @return
     */
    @ApiOperation("商品详情")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "productId", required = true, value = "商品Id")
    })
    @GetMapping("/details")
    public ResponseJson<ProductVo> productDetails(Integer productId) {
        return productService.productDetails(productId);
    }
}
